@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: about.py 738 2007-02-20 15:29:26Z piotrek $'
+__revision__ = '$Id: about.py 827 2007-08-05 18:41:38Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
@@ -58,23 +58,39 @@ class AboutDialog:
 			_("Czech") + ":\n\t" + \
 				"Blondak <blondak@neser.cz>,\n\t" + \
 				"Ondra 'Kepi' Kudlík <kepi@igloonet.cz>\n" + \
+			_("Danish") + ":\n\t" + \
+				"Joe Dalton <joedalton2@yahoo.dk>\n" + \
+			_("Dutch") + ":\n\t" + \
+				"Marcel Dijkstra <mdtje@hotmail.com>\n" + \
+			_("Japanese") + ":\n\t" + \
+				"Jack Nihil <jnihil@gmail.com>\n" + \
 			_("French") + ":\n\t" + \
+				"Guillaume Pratte <guillaume@guillaumepratte.net>" + \
+				"original translation from:\n\t" + \
 				"Pierre-Luc Lévy <pllevy@free.fr>\n" + \
 			_("German") + ":\n\t" + \
 				"Jessica Katharina Parth <Jessica.K.P@women-at-work.org>,\n\t" + \
 				"original translation from:\n\t" + \
 				"Christian Sagmueller <christian@sagmueller.net>,\n\t" + \
 				"Malte Wiemann <ryan2057@gmx.de>\n" + \
+			_("Greek") + ":\n\t" + \
+				"Ioannis Koniaris <ikoniari@csd.auth.gr>\n" + \
 			_("Italian") + ":\n\t" + \
 				"Diego Porcelli <diego.p77@gmail.com>\n" + \
 			_("Polish") + ":\n\t" + \
 				"Piotr Ozarowski <ozarow+griffith@gmail.com>\n" + \
 			_("Portuguese") + ":\n\t" + \
 				"Vasco Nunes <vasco.m.nunes@gmail.com>\n" + \
+			_("Russian") + ":\n\t" + \
+				"Pavel V. Kulikov <kulikovpv8256@yandex.ru>\n" + \
+			_("Simplified Chinese") + ":\n\t" + \
+				"kempson <kempson.chen@gmail.com>\n" + \
 			_("Spanish") + ":\n\t" + \
 				"Daniel Ucero <escaranbujo@gmail.com>\n" + \
 			_("Swedish") + ":\n\t" + \
-				"Daniel Nylander <po@danielnylander.se>\n" \
+				"Daniel Nylander <po@danielnylander.se>\n" + \
+			_("Turkish") + ":\n\t" + \
+				"transorlate <iloveshorts@hotmail.com>\n" \
 		)
 		logo_file = os.path.abspath(os.path.join(images_dir, 'griffith.png'))
 		logo = gtk.gdk.pixbuf_new_from_file(logo_file)
