@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: dbupgrade.py 731 2007-02-12 22:53:28Z piotrek $'
+__revision__ = '$Id: dbupgrade.py 793 2007-06-30 14:53:26Z piotrek $'
 
 # Copyright (c) 2005-2006 Vasco Nunes, Piotr Ożarowski
 #
@@ -128,13 +128,17 @@ def convert_from_old_db(self, source_file, destination_file):	#{{{
 		try:
 			import sqlite
 			from sqlite import DatabaseError
-		except:
+		except ImportError:
 			print 'Old DB conversion: please install pysqlite legacy (v1.0)'
 			gutils.warning(self,_("Old DB conversion: please install pysqlite legacy (v1.0)"))
 			return False
 	else:
-		from pysqlite2 import dbapi2 as sqlite
-		from pysqlite2.dbapi2 import DatabaseError
+		try:	# Python 2.5
+			from sqlite3 import dbapi2 as sqlite
+			from sqlite3.dbapi2 import DatabaseError
+		except ImportError: # Python < 2.5 - try to use pysqlite2
+			from pysqlite2 import dbapi2 as sqlite
+			from pysqlite2.dbapi2 import DatabaseError
 
 	if os.path.isfile(destination_file):
 		# rename destination_file if it already exist
@@ -196,15 +200,15 @@ def convert_from_old_db(self, source_file, destination_file):	#{{{
 	old_cursor.execute("DELETE FROM collections WHERE name = 'None'")
 	old_cursor.execute("DELETE FROM languages WHERE name = ''")
 	
-	self.config['db_type'] = 'sqlite'
-	self.config['default_db'] = 'griffith.db'
+	self.config.set('type','sqlite', section='database')
+	self.config.set('file', 'griffith.db', section='database')
 	self.config['posters'] = 'posters'
-	self.config['color'] = 0
-	self.config['condition'] = 0
-	self.config['layers'] = 0
-	self.config['media'] = 0
-	self.config['region'] = 0
-	self.config['vcodec'] = 0
+	self.config.set('color', 0, section='defaults')
+	self.config.set('condition', 0, section='defaults')
+	self.config.set('layers', 0, section='defaults')
+	self.config.set('media', 0, section='defaults')
+	self.config.set('region', 0, section='defaults')
+	self.config.set('vcodec', 0, section='defaults')
 	self.locations['posters'] = os.path.join(self.locations['home'], 'posters')
 	new_db = GriffithSQL(self.config, self.debug, self.locations['home'])
 
@@ -303,8 +307,10 @@ def convert_from_old_db(self, source_file, destination_file):	#{{{
 	for i in old_cursor.fetchall():
 		o = new_db.Movie()
 		o.number = digits_only(i[6])
-		o.volume_id = volume_mapper[i[1]]
-		o.collection_id = collection_mapper[i[2]]
+		if volume_mapper.has_key(i[1]):
+			o.volume_id = volume_mapper[i[1]]
+		if collection_mapper.has_key(i[2]):
+			o.collection_id = collection_mapper[i[2]]
 		o.o_title = i[3][:255]
 		o.title = i[4][:255]
 		o.director = i[5][:255]
@@ -322,7 +328,8 @@ def convert_from_old_db(self, source_file, destination_file):	#{{{
 		o.trailer = i[18][:255]
 		o.rating = digits_only(i[19])
 		#o.loaned = bool(i[20]) # updated later
-		o.medium_id = medium_mapper[int(i[21])]
+		if medium_mapper.has_key(int(i[21])):
+			o.medium_id = medium_mapper[int(i[21])]
 		o.media_num = digits_only(i[22])
 		o.notes = i[23]
 		o.seen = bool(i[24])
