@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: edit.py 726 2007-01-27 20:12:37Z piotrek $'
+__revision__ = '$Id: edit.py 770 2007-06-12 22:32:20Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 
@@ -130,7 +130,7 @@ def fetch_bigger_poster(self):
 	current_poster = movie.image
 	amazon.setLicense("04GDDMMXX8X9CJ1B22G2")
 
-	locale = self.config.get('amazon_locale', 0)
+	locale = self.config.get('amazon_locale', 0, section='add')
 	if locale == 1:
 		locale = 'uk'
 	elif locale == 2:
@@ -219,6 +219,10 @@ def get_poster(self, f, result, current_poster):
 		if im.size == (1,1):
 			from urllib import FancyURLopener, urlretrieve
 			url = FancyURLopener().open("http://www.amazon.com/gp/product/images/%s" % result[f].Asin).read()
+			if url.find('no-img-sm._V47056216_.gif') > 0:
+				self.debug.show('No image available')
+				gutils.warning(self, _("Sorry. This movie is listed but has no poster available at Amazon.com."))
+				return False
 			url = gutils.after(url, 'id="imageViewerDiv"><img src="')
 			url = gutils.before(url, '" id="prodImage"')
 			urlretrieve(url, file_to_copy)
