@@ -1,6 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-__revision__ = '$Id: gconsole.py 674 2007-01-05 23:01:29Z piotrek $'
+__revision__ = '$Id: gconsole.py 770 2007-06-12 22:32:20Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 
@@ -26,15 +26,17 @@ import getopt
 import sys
 import gutils
 
+options = ('hDCo:t:d:c:y:s:', ('help', 'debug', 'sqlecho', 'clean', 'check-dep',
+	'show-dep', 'original_title=', 'title=', 'director=', 'cast=', 'year=',
+	'sort=', 'seen=', 'loaned=', 'number=', 'runtime=', 'rating=', 'home=',
+	'config='))
+
 def check_args(self):
 	self._tmp_home = None
+	self._tmp_config = 'griffith.cfg'
 	if len(sys.argv)>1:
 		try:
-			opts, args = getopt.getopt(sys.argv[1:], 'hDCo:t:d:c:y:s:',
-				('help', 'debug', 'sqlecho', 'clean', 'check-dep', 'show-dep',
-				'original_title=', 'title=', 'director=', 'cast=', 'year=',
-				'sort=', 'seen=', 'loaned=', 'number=', 'runtime=',
-				'rating=', 'home='))
+			opts, args = getopt.getopt(sys.argv[1:], options[0], options[1])
 		except getopt.GetoptError:
 			# print help information and exit:
 			con_usage()
@@ -48,6 +50,8 @@ def check_args(self):
 				self.debug.set_debug()
 			elif o == '--home':
 				self._tmp_home = a # see initialize.locations()
+			elif o == '--config':
+				self._tmp_config = a # griffith.__init__
 			elif o == '--check-dep':
 				check_dependencies()
 				sys.exit()
@@ -55,15 +59,10 @@ def check_args(self):
 				show_dependencies()
 				sys.exit()
 
-	
 def check_args_with_db(self):
 	if len(sys.argv)>1:
 		try:
-			opts, args = getopt.getopt(sys.argv[1:], 'hDCo:t:d:c:y:s:',
-				('help', 'debug', 'sqlecho', 'clean', 'check-dep', 'show-dep',
-				'original_title=', 'title=', 'director=', 'cast=', 'year=',
-				'sort=', 'seen=', 'loaned=', 'number=', 'runtime=',
-				'rating=', 'home='))
+			opts, args = getopt.getopt(sys.argv[1:], options[0], options[1])
 		except getopt.GetoptError:
 			# print help information and exit:
 			con_usage()
