@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: gdebug.py 179 2006-02-01 22:24:24Z iznogoud $'
+__revision__ = '$Id: gdebug.py 674 2007-01-05 23:01:29Z piotrek $'
 
-# Copyright (c) 2005 Vasco Nunes
+# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@ __revision__ = '$Id: gdebug.py 179 2006-02-01 22:24:24Z iznogoud $'
 class GriffithDebug:
 	debug_mode = None
 	
-	def __init__(self):
-		self.debug_mode = False
+	def __init__(self, mode=False):
+		self.debug_mode = mode
 
-	def set_debug(self):
-		self.debug_mode = True
+	def set_debug(self, mode=True):
+		self.debug_mode = mode
 
 	def show(self, txt):
 		if self.debug_mode:
