@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: gutils.py 711 2007-01-16 13:34:35Z piotrek $'
+__revision__ = '$Id: gutils.py 828 2007-08-05 19:22:37Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
@@ -24,11 +24,14 @@ __revision__ = '$Id: gutils.py 711 2007-01-16 13:34:35Z piotrek $'
 from gettext import gettext as _
 import string
 import os
-import gtk
+try:
+	import gtk
+	import gobject
+except:
+	pass
 import htmlentitydefs
 import re
 import webbrowser
-import gobject
 
 url_re = re.compile('^\w+://')
 entity = re.compile(r'\&.\w*?\;')
@@ -189,8 +192,9 @@ def save_pixmap(self, pixmap, filename):
 
 def clean(text):
 	t = strip_tags(text)
-	t = string.replace(t, "&nbsp;", " ")
-	t = string.replace(t,'&#34;',"")
+	t = string.replace(t, '&nbsp;', ' ')
+	t = string.replace(t, '&#34;', '')
+	t = string.replace(t, '&#160;', ' ')
 	return string.strip(t)
 
 def gdecode(txt, encode):
@@ -205,6 +209,7 @@ def error(self, msg, parent=None):
 	dialog = gtk.MessageDialog(parent,
 			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
 			gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, msg)
+	dialog.set_skip_taskbar_hint(False)
 	dialog.run()
 	dialog.destroy()
 
@@ -212,6 +217,7 @@ def urllib_error(msg, parent=None):
 	dialog = gtk.MessageDialog(parent,
 			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
 			gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, msg)
+	dialog.set_skip_taskbar_hint(False)
 	dialog.run()
 	dialog.destroy()
 
@@ -219,6 +225,7 @@ def warning(self, msg, parent=None):
 	dialog = gtk.MessageDialog(parent,
 			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
 			gtk.MESSAGE_WARNING, gtk.BUTTONS_OK, msg)
+	dialog.set_skip_taskbar_hint(False)
 	dialog.run()
 	dialog.destroy()
 
@@ -226,6 +233,7 @@ def info(self, msg, parent=None):
 	dialog = gtk.MessageDialog(parent,
 			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
 			gtk.MESSAGE_INFO, gtk.BUTTONS_OK, msg)
+	dialog.set_skip_taskbar_hint(False)
 	dialog.run()
 	dialog.destroy()
 
@@ -237,6 +245,7 @@ def question(self, msg, cancel=1, parent=None):
 	dialog.add_buttons(gtk.STOCK_YES, gtk.RESPONSE_YES,
 			gtk.STOCK_NO, gtk.RESPONSE_NO)
 	dialog.set_default_response(gtk.RESPONSE_NO)
+	dialog.set_skip_taskbar_hint(False)
 	response = dialog.run()
 	dialog.destroy()
 	return response
@@ -407,17 +416,29 @@ def get_dependencies():
 		'debian_req'	: '0.3.0-1'
 	})
 	try:
-		import pysqlite2
-		version = True
-		# TODO: check if "pysqlite" is in version >= 2
-	except:
+		import sqlite3
+		version = sqlite3.version
+	except ImportError:
 		version = False
-	depend.append({'module': 'pysqlite2',
-		'version'	: version,
-		'url'		: 'http://initd.org/tracker/pysqlite',
-		'debian'	: 'python-pysqlite2',
-		'debian_req'	: '2.3.0-1'
-	})
+	if version is False:
+		try:
+			import pysqlite2
+			version = True
+		except:
+			version = False
+		depend.append({'module': 'pysqlite2',
+			'version'	: version,
+			'url'		: 'http://initd.org/tracker/pysqlite',
+			'debian'	: 'python-pysqlite2',
+			'debian_req'	: '2.3.0-1'
+		})
+	else:
+		depend.append({'module': 'sqlite3',
+			'version'	: version,
+			'url'		: 'http://www.python.org',
+			'debian'	: 'python',
+			'debian_req'	: '2.5'
+		})
 	try:
 		import reportlab
 		version = reportlab.Version
@@ -523,3 +544,33 @@ def digits_only(s, maximum=None):
 			return maximum
 		else:
 			return s
+
+def copytree(src, dst, symlinks=False):
+	"""Recursively copy a directory tree using copy2().
+
+	This is shutil's copytree modified version
+	"""
+	from shutil import copy2
+	names = os.listdir(src)
+	if not os.path.isdir(dst):
+		os.mkdir(dst)
+	errors = []
+	for name in names:
+		srcname = os.path.join(src, name)
+		dstname = os.path.join(dst, name)
+		try:
+			if symlinks and os.path.islink(srcname):
+				linkto = os.readlink(srcname)
+				os.symlink(linkto, dstname)
+			elif os.path.isdir(srcname):
+				copytree(srcname, dstname, symlinks)
+			else:
+				copy2(srcname, dstname)
+		except (IOError, os.error), why:
+			errors.append((srcname, dstname, why))
+		# catch the Error from the recursive copytree so that we can
+		# continue with other files
+		except EnvironmentError, err:
+			errors.extend(err.args[0])
+	if errors:
+		raise EnvironmentError, errors
