@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: initialize.py 711 2007-01-16 13:34:35Z piotrek $'
+__revision__ = '$Id: initialize.py 812 2007-07-25 22:38:27Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
@@ -21,7 +21,6 @@ __revision__ = '$Id: initialize.py 711 2007-01-16 13:34:35Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import sys
 import os
 import string
@@ -30,7 +29,8 @@ import gutils
 import gobject
 import gettext
 import platform
-import locale
+from gettext import gettext as _
+from locale import getdefaultlocale
 
 try:
 	import gtkspell
@@ -39,6 +39,7 @@ except:
 	spell_support = 0
 
 def locations(self):
+	defaultLang, defaultEnc = getdefaultlocale()
 	locations = {}
 	locations['exec'] = os.path.abspath(os.path.dirname(sys.argv[0])) # deprecated
 	locations['lib']  = os.path.dirname(__file__)
@@ -46,7 +47,7 @@ def locations(self):
 	if os.name == 'nt' or os.name == 'win32':
 		import winshell
 		mydocs = winshell.my_documents()
-		locations['home']           = os.path.join(mydocs, 'griffith')
+		locations['home']           = os.path.join(mydocs, 'griffith').decode(defaultEnc)
 		#locations['home']           = os.path.join(os.path.expanduser('~'), 'griffith')
 		locations['movie_plugins']  = "%s\\lib\\plugins\\movie" % locations['exec']
 		locations['export_plugins'] = "%s\\lib\\plugins\\export" % locations['exec']
@@ -60,14 +61,13 @@ def locations(self):
 		# windows hack for locale setting
 		lang = os.getenv('LANG')
 		if lang is None:
-			defaultLang, defaultEnc = locale.getdefaultlocale()
 			if defaultLang:
 				lang = defaultLang
 		if lang:
 			os.environ['LANG'] = lang
 
 	elif os.name == 'posix':
-		locations['home']  = os.path.join(os.path.expanduser('~'), ".griffith")
+		locations['home']  = os.path.join(os.path.expanduser('~'), '.griffith').decode(defaultEnc)
 		locations['share'] = os.path.abspath(os.path.join(locations['lib'], '..'))
 		locations['glade'] = os.path.join(locations['share'], 'glade')
 		locations['i18n']  = os.path.abspath(os.path.join(locations['share'], '..', 'locale'))
@@ -77,7 +77,7 @@ def locations(self):
 		locations['movie_plugins']  = os.path.join(locations['lib'], 'plugins', 'movie')
 		locations['export_plugins'] = os.path.join(locations['lib'], 'plugins', 'export')
 		locations['images']  = os.path.join(locations['share'], 'images')
-		locations['desktop'] = os.path.join(os.path.expanduser('~'), 'Desktop')
+		locations['desktop'] = os.path.join(os.path.expanduser('~'), 'Desktop').decode(defaultEnc)
 	else:
 		print 'Operating system not supported'
 		sys.exit()
@@ -113,15 +113,19 @@ def locations(self):
 	return locations
 
 def location_posters(locations, config):
-	if config['posters'] is not None:
-		locations['posters']  = os.path.join(locations['home'], config['posters'])
-	elif config['db_type'] == 'sqlite':
-		config['posters'] = 'posters'
-		locations['posters'] = os.path.join(locations['home'], 'posters')
+	if config.get('posters', None) is not None:
+		locations['posters']  = os.path.join(locations['home'], config.get('posters'))
+	elif config.get('type', 'sqlite', section='database') == 'sqlite':
+		dbname = config.get('name', 'griffith', section='database')
+		if dbname != 'griffith':
+			config['posters'] = 'posters_sqlite_' + dbname
+		else:
+			config['posters'] = 'posters'
+		locations['posters'] = os.path.join(locations['home'], config.get('posters'))
 		config.save()
 	else:
-		config['posters'] = "posters_%(db_type)s_%(db_host)s_%(db_port)s_%(db_name)s_%(db_user)s" % config
-		locations['posters'] = os.path.join(locations['home'], config['posters'])
+		config['posters'] = "posters_%(type)s_%(host)s_%(port)s_%(name)s_%(user)s" % config.toDict('database')
+		locations['posters'] = os.path.join(locations['home'], config.get('posters'))
 		config.save()
 	# check if posters dir exists
 	if not os.path.isdir(locations['posters']):
@@ -160,7 +164,7 @@ def i18n(self, location):
 
 def toolbar(self):
 	"""if toolbar is hide in config lets hide the widget"""
-	if not self.config.get('view_toolbar'):
+	if not self.config.get('view_toolbar', 'True', section='window'):
 		self.widgets['toolbar'].hide()
 		self.widgets['menu']['toolbar'].set_active(False)
 
@@ -238,6 +242,8 @@ def lang_treeview(self):
 	combo.set_property('has-entry', False)
 	combo.connect('edited', self.on_tv_lang_combo_edited, 0)
 	column=gtk.TreeViewColumn(_('Language'), combo, text=0)
+	column.set_property('min-width', 80)
+	column.set_property('resizable', True)
 	column.set_sort_column_id(0)
 	treeview.append_column(column)
 	
@@ -258,6 +264,8 @@ def lang_treeview(self):
 	combo.set_property('has-entry', False)
 	combo.connect('edited', self.on_tv_lang_combo_edited, 1)
 	column=gtk.TreeViewColumn(_('Type'), combo, text=1)
+	column.set_property('min-width', 80)
+	column.set_property('resizable', True)
 	column.set_sort_column_id(1)
 	treeview.append_column(column)
 
@@ -271,6 +279,8 @@ def lang_treeview(self):
 	combo.set_property('has-entry', False)
 	combo.connect('edited', self.on_tv_lang_combo_edited, 2)
 	column=gtk.TreeViewColumn(_('Codec'), combo, text=2)
+	column.set_property('min-width', 80)
+	column.set_property('resizable', True)
 	column.set_sort_column_id(2)
 	treeview.append_column(column)
 	
@@ -284,6 +294,8 @@ def lang_treeview(self):
 	combo.set_property('has-entry', False)
 	combo.connect('edited', self.on_tv_lang_combo_edited, 3)
 	column=gtk.TreeViewColumn(_('Channels'), combo, text=3)
+	column.set_property('min-width', 80)
+	column.set_property('resizable', True)
 	column.set_sort_column_id(3)
 	treeview.append_column(column)
 	
@@ -297,6 +309,8 @@ def lang_treeview(self):
 	combo.set_property('has-entry', False)
 	combo.connect('edited', self.on_tv_lang_combo_edited, 4)
 	column=gtk.TreeViewColumn(_('Subtitle format'), combo, text=4)
+	column.set_property('min-width', 80)
+	column.set_property('resizable', True)
 	column.set_sort_column_id(4)
 	treeview.append_column(column)
 	
@@ -312,12 +326,13 @@ def movie_plugins(self):
 	self.plugins.sort()
 	self.d_plugin = 0
 	mcounter = 0
+	default_plugin = self.config.get('default_movie_plugin')
 	for p in self.plugins:
 		plugin_module = os.path.basename(p).replace('.py','')
 		plugin_name = plugin_module.replace('PluginMovie','')
 		self.widgets['add']['source'].append_text(plugin_name)
 		self.widgets['preferences']['default_plugin'].append_text(plugin_name)
-		if self.config.get('default_movie_plugin') == plugin_name:
+		if plugin_name == default_plugin:
 			self.widgets['preferences']['default_plugin'].set_active(mcounter)
 			self.d_plugin = mcounter
 		mcounter = mcounter + 1
@@ -552,26 +567,24 @@ def gtkspell(self):
 	global spell_support
 	spell_error = False
 	if self.posix and spell_support:
-		if self.config.get('use_gtkspell', False) == 'True':
-			if self.config.get('spell_notes', True) == 'True' and \
-				self.config.get('spell_lang')!='':
+		if self.config.get('gtkspell', False, section='spell') == True:
+			if self.config.get('notes', True, section='spell') == True and self.config.get('lang', section='spell') != '':
 				try:
-					self.notes_spell = gtkspell.Spell(self.widgets['add']['cast'], self.config.get('spell_lang'))
+					self.notes_spell = gtkspell.Spell(self.widgets['add']['cast'], self.config.get('lang', section='spell'))
 				except:
 					spell_error = True
-			if self.config.get('spell_plot', True)=='True' and \
-				self.config.get('spell_lang')!='':
+			if self.config.get('plot', True, section='spell')==True and self.config.get('lang', section='spell') != '':
 				try:
-					self.plot_spell = gtkspell.Spell(self.widgets['add']['plot'], self.config.get('spell_lang'))
+					self.plot_spell = gtkspell.Spell(self.widgets['add']['plot'], self.config.get('lang', section='spell'))
 				except:
 					spell_error = True
 			if spell_error:
 				self.debug.show('Dictionary not available. Spellcheck will be disabled.')
-				if not self.config.get('spell_notify', False):
+				if not self.config.get('notified', False, section='spell'):
 					gutils.info(self, _("Dictionary not available. Spellcheck will be disabled. \n" + \
-						"Please install the aspell-%s package or adjust the spellchekcer preferences.")%self.config.get('spell_lang'), \
+						"Please install the aspell-%s package or adjust the spellchekcer preferences.")%self.config.get('lang', section='spell'), \
 						self.widgets['preferences']['window'])
-					self.config['spell_notify'] = True
+					self.config.set('notified', True, section='spell')
 					self.config.save()
 	else:
 		self.debug.show('Spellchecker is not available')
@@ -580,25 +593,21 @@ def preferences(self):
 	self.widgets['preferences']['db_type'].insert_text(0,'SQLite3 (internal)')
 	self.widgets['preferences']['db_type'].insert_text(1,'PostgreSQL')
 	self.widgets['preferences']['db_type'].insert_text(2,'MySQL')
-	if self.config.has_key('db_host'):
-		self.widgets['preferences']['db_host'].set_text(self.config['db_host'])
-	if self.config.has_key('db_port'):
-		self.widgets['preferences']['db_port'].set_value(int(self.config['db_port']))
-	if self.config.has_key('db_user'):
-		self.widgets['preferences']['db_user'].set_text(self.config['db_user'])
-	if self.config.has_key('db_passwd'):
-		self.widgets['preferences']['db_passwd'].set_text(self.config['db_passwd'])
-	if self.config.has_key('db_name'):
-		self.widgets['preferences']['db_name'].set_text(self.config['db_name'])
-	if self.config.has_key('db_type') and self.config['db_type'] != 'sqlite':
-		self.widgets['preferences']['db_details'].set_sensitive(True)
-		if self.config['db_type'] == 'postgres':
-			self.widgets['preferences']['db_type'].set_active(1)
-		elif self.config['db_type'] == 'mysql':
-			self.widgets['preferences']['db_type'].set_active(2)
+	self.widgets['preferences']['db_type'].insert_text(3,'Microsoft SQL')
+	self.widgets['preferences']['db_host'].set_text(self.config.get('host', '', section='database'))
+	self.widgets['preferences']['db_port'].set_value(int(self.config.get('port', 0, section='database')))
+	self.widgets['preferences']['db_user'].set_text(self.config.get('user', '', section='database'))
+	self.widgets['preferences']['db_passwd'].set_text(self.config.get('passwd', '', section='database'))
+	self.widgets['preferences']['db_name'].set_text(self.config.get('name', '', section='database'))
+	db_type = self.config.get('type', 'sqlite', section='database')
+	if db_type == 'postgres':
+		self.widgets['preferences']['db_type'].set_active(1)
+	elif db_type == 'mysql':
+		self.widgets['preferences']['db_type'].set_active(2)
+	elif db_type == 'mssql':
+		self.widgets['preferences']['db_type'].set_active(3)
 	else:
 		self.widgets['preferences']['db_type'].set_active(0)
-		self.widgets['preferences']['db_details'].set_sensitive(False)
 
 def fill_volumes_combo(self, default=0):
 	self.widgets['add']['volume'].get_model().clear()
@@ -728,8 +737,8 @@ def media_combos(self):
 	self.widgets['preferences']['medium_name'].show_all()
 	self.widgets['add']['media'].show_all()
 	self.widgets['preferences']['media'].show_all()
-	if self.config.has_key('media'):
-		pos = gutils.findKey(self.config['media'], self.media_ids)
+	if self.config.has_key('media', section='defaults'):
+		pos = gutils.findKey(self.config.get('media', section='defaults'), self.media_ids)
 		if pos  is not None:
 			self.widgets['preferences']['media'].set_active(int(pos))
 		else:
@@ -761,7 +770,7 @@ def vcodec_combos(self):
 	self.widgets['add']['vcodec'].show_all()
 	self.widgets['preferences']['vcodec'].show_all()
 	
-	pos = gutils.findKey(self.config.get('vcodec', 0), self.vcodecs_ids)
+	pos = gutils.findKey(self.config.get('vcodec', 0, section='defaults'), self.vcodecs_ids)
 	if pos is not None:
 		self.widgets['preferences']['vcodec'].set_active(int(pos))
 	else:
