@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: main_treeview.py 730 2007-02-12 20:31:48Z piotrek $'
+__revision__ = '$Id: main_treeview.py 774 2007-06-17 20:35:24Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 
@@ -95,22 +95,39 @@ def set_details(self, item=None):#{{{
 	else:
 		w['genre'].set_text('')
 	if item.has_key('cond') and item['cond']:
-		w['condition'].set_markup("<i>%s</i>" % self._conditions[item['cond']])
+		if str(item['cond']) in [ str(i) for i in range(len(self._conditions)) ]:
+			w['condition'].set_markup("<i>%s</i>" % self._conditions[item['cond']])
+		else:
+			w['condition'].set_text('')
+			self.debug.show("Wrong value in 'condition' field (movie_id=%s, cond=%s)" % (item['movie_id'], item['cond']))
 	else:
 		w['condition'].set_text('')
 	if item.has_key('region') and item['region']:
-		w['region'].set_markup("<i>%s</i>" % gutils.html_encode(item['region']))
-		if int(item['region']) < 9:
-			self.widgets['tooltips'].set_tip(w['region'], self._regions[int(item['region'])])
+		if str(item['region']) in [ str(i) for i in range(len(self._regions)) ]:
+			w['region'].set_markup("<i>%s</i>" % gutils.html_encode(item['region']))
+			if int(item['region']) < 9:
+				self.widgets['tooltips'].set_tip(w['region'], self._regions[int(item['region'])])
+		else:
+			self.debug.show("Wrong value in 'region' field (movie_id=%s, region=%s)" % (item['movie_id'], item['region']))
+			w['region'].set_text('')
+			self.widgets['tooltips'].set_tip(w['region'], self._regions[0]) # N/A
 	else:
 		w['region'].set_text('')
 		self.widgets['tooltips'].set_tip(w['region'], self._regions[0]) # N/A
 	if item.has_key('layers') and item['layers']:
-		w['layers'].set_markup("<i>%s</i>" % self._layers[item['layers']])
+		if str(item['layers']) in [ str(i) for i in range(len(self._layers)) ]:
+			w['layers'].set_markup("<i>%s</i>" % self._layers[item['layers']])
+		else:
+			self.debug.show("Wrong value in 'layers' field (movie_id=%s, layers=%s)" % (item['movie_id'], item['layers']))
+			w['layers'].set_text('')
 	else:
 		w['layers'].set_text('')
 	if item.has_key('color') and item['color']:
-		w['color'].set_markup("<i>%s</i>" % self._colors[item['color']])
+		if str(item['color']) in [ str(i) for i in range(len(self._colors)) ]:
+			w['color'].set_markup("<i>%s</i>" % self._colors[item['color']])
+		else:
+			self.debug.show("Wrong value in 'color' field (movie_id=%s, color=%s)" % (item['movie_id'], item['color']))
+			w['color'].set_markup('')
 	else:
 		w['color'].set_markup('')
 	if item.has_key('classification') and item['classification']:
@@ -192,10 +209,7 @@ def set_details(self, item=None):#{{{
 		w['picture_button'].set_sensitive(False)
 	w['picture'].set_from_file(image_path)
 	# ratig
-	try:
-		rimage = int(str(self.config.get('rating_image')))
-	except:
-		rimage = 0
+	rimage = int(self.config.get('rating_image', 0))
 	if rimage:
 		prefix = ''
 	else:
@@ -344,8 +358,8 @@ def populate(self, movies=None, where=None):#{{{
 				movies.append_whereclause(self.db.Movie.c.collection_id==col_id)
 		
 		# select sort column
-		sort_column_name = self.config.get('sortby', 'number')
-		sort_reverse = self.config.get('sortby_reverse', False)
+		sort_column_name = self.config.get('sortby', 'number', section='mainlist')
+		sort_reverse = self.config.get('sortby_reverse', False, section='mainlist')
 		for i in sort_column_name.split(','):
 			if self.db.Movie.c.has_key(i):
 				if sort_reverse:
@@ -372,23 +386,23 @@ def populate(self, movies=None, where=None):#{{{
 	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str)
 
 	# check preferences to hide or show columns
-	if self.config.get('view_number', 'True') == 'True':
+	if self.config.get('number', True, 'mainlist') == True:
 		self.number_column.set_visible(True)
 	else:
 		self.number_column.set_visible(False)
-	if self.config.get('view_otitle', 'True') == 'True':
+	if self.config.get('otitle', True, 'mainlist') == True:
 		self.otitle_column.set_visible(True)
 	else:
 		self.otitle_column.set_visible(False)
-	if self.config.get('view_title', 'True') == 'True':
+	if self.config.get('title', True, 'mainlist') == True:
 		self.title_column.set_visible(True)
 	else:
 		self.title_column.set_visible(False)
-	if self.config.get('view_director', 'True') == 'True':
+	if self.config.get('director', True, 'mainlist') == True:
 		self.director_column.set_visible(True)
 	else:
 		self.director_column.set_visible(False)
-	if self.config.get('view_image', 'True') == 'True':
+	if self.config.get('image', True, 'mainlist') == True:
 		self.image_column.set_visible(True)
 	else:
 		self.image_column.set_visible(False)
@@ -398,7 +412,7 @@ def populate(self, movies=None, where=None):#{{{
 		
 		self.treemodel.set_value(myiter,0,'%004d' % int(movie.number))
 
-		if self.config.get('view_image', 'True') == 'True':
+		if self.config.get('image', True, section='mainlist') == True:
 			tmp_dest = self.locations['posters']
 			tmp_img = os.path.join(tmp_dest, "t_%s.jpg" % str(movie.image))
 			if movie.image and os.path.isfile(tmp_img):
