@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportCSV.py 674 2007-01-05 23:01:29Z piotrek $'
+__revision__ = '$Id: PluginExportCSV.py 773 2007-06-17 19:41:19Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 #
@@ -35,7 +35,7 @@ plugin_version = "0.2"
 
 class ExportPlugin:
 
-    def __init__(self, database, locations, parent, debug):
+    def __init__(self, database, locations, parent, debug, **kwargs):
         self.db = database
         self.locations = locations
         self.parent = parent
