@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: PluginExportHTML.py 674 2007-01-05 23:01:29Z piotrek $'
+__revision__ = '$Id: PluginExportHTML.py 828 2007-08-05 19:22:37Z piotrek $'
 
 # Copyright (c) 2005-2007 Piotr Ożarowski
 #
@@ -36,7 +36,7 @@ plugin_name         = 'HTML'
 plugin_description  = _('Plugin exports data using templates')
 plugin_author       = 'Piotr Ożarowski'
 plugin_author_email = 'ozarow+griffith@gmail.com'
-plugin_version      = '3.7'
+plugin_version      = '3.8'
 
 class ExportPlugin(gtk.Window):
 	#==[ configuration - default values ]==========={{{
@@ -120,7 +120,7 @@ class ExportPlugin(gtk.Window):
 	}
 	#}}}
 
-	def __init__(self, database, locations, parent, debug):#{{{
+	def __init__(self, database, locations, parent_window, debug, **kwargs):#{{{
 		self.db = database
 		self.debug = debug
 		self.locations = locations
@@ -546,6 +546,13 @@ class ExportPlugin(gtk.Window):
 			except:
 				gutils.error(self,_("Can't create %s!") % config['exported_dir'])
 				return 2
+			
+		data_path = os.path.join(self.locations['share'], 'export_templates', self.templates[tid]['dir'], 'data')
+		if os.path.isdir(data_path):
+			try:
+				gutils.copytree(data_path, config['exported_dir'])
+			except Exception, err:
+				gutils.warning(self, str(err))
 
 		if fields['image']:
 			# import modules needed later
