@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportXML.py 674 2007-01-05 23:01:29Z piotrek $'
+__revision__ = '$Id: PluginExportXML.py 773 2007-06-17 19:41:19Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
@@ -36,10 +36,10 @@ plugin_version = "0.1"
 
 class ExportPlugin:
 
-	def __init__(self, database, locations, parent, debug):
+	def __init__(self, database, locations, parent_window, debug, **kwargs):
 		self.db = database
 		self.locations = locations
-		self.parent = parent
+		self.parent = parent_window
 		self.export_xml()
 
 	def export_xml(self):
