@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__revision__ = '$Id: PluginMovieFDb.py 684 2007-01-07 00:59:45Z piotrek $'
+__revision__ = '$Id: PluginMovieFDb.py 826 2007-08-05 18:16:17Z piotrek $'
 
 # Copyright (c) 2006-2007 Piotr Ozarowski
 #
@@ -25,6 +25,7 @@ from gettext import gettext as _
 import gutils
 import movie
 import string
+import re
 
 plugin_name		= 'FDb'
 plugin_description	= 'Internetowa baza filmowa'
@@ -32,9 +33,11 @@ plugin_url		= 'fdb.pl'
 plugin_language		= _('Polish')
 plugin_author		= 'Piotr Ożarowski'
 plugin_author_email	= '<ozarow+griffith@gmail.com>'
-plugin_version		= '1.6'
+plugin_version		= '1.8'
 
 class Plugin(movie.Movie):
+	TRAILER_PATTERN = re.compile('\s*<a\shref=[\'"](.*?)["\'].*?>\(zobacz\szwiastun\)</a>')
+	
 	def __init__(self, movie_id):
 		from md5 import md5
 		self.movie_id = md5(movie_id).hexdigest()
@@ -47,7 +50,10 @@ class Plugin(movie.Movie):
 	def get_image(self):
 		self.image_url = gutils.trim(self.page, 'class="moviePosterTable"', '</td>');
 		self.image_url = gutils.trim(self.image_url,' src="',"\"\n")
-		self.image_url = "http://fdb.pl%s" % self.image_url
+		if self.image_url.endswith('no_picture.png'):
+			self.image_url = ''
+		else:
+			self.image_url = "http://fdb.pl%s" % self.image_url
 
 	def get_o_title(self):
 		self.o_title = gutils.trim(self.page, '<h2>', '</h2>')
@@ -78,6 +84,7 @@ class Plugin(movie.Movie):
 
 	def get_plot(self):
 		self.plot = gutils.trim(self.page,'>Opis filmu:</div>','</div>')
+		self.plot = self.TRAILER_PATTERN.sub('', self.plot)
 
 	def get_year(self):
 		self.year = gutils.trim(self.page,' class="movieYear">(', ')</span>')
@@ -111,7 +118,9 @@ class Plugin(movie.Movie):
 		self.site = self.url
 
 	def get_trailer(self):
-		self.trailer = ''
+		trailer_url = self.TRAILER_PATTERN.findall(self.page)
+		if trailer_url:
+			self.trailer = trailer_url[0]
 
 	def get_country(self):
 		self.country = gutils.trim(self.page,">Kraj:</span>\n",'</div>')
@@ -147,7 +156,10 @@ class SearchPlugin(movie.SearchMovie):
 			elements = string.split(self.page,'<div class="searchItem">')
 			if len(elements)>0:
 				for element in elements:
-					self.ids.append(gutils.trim(element, '<a href="', '"'))
+					tmpId = gutils.trim(element, '<a href="', '"')
+					if tmpId.endswith('dodajNowy.php'):
+						continue
+					self.ids.append(tmpId)
 					element = gutils.strip_tags(
 						gutils.trim(element, '">', '</div>'))
 					element = element.replace("\n", '')
