@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__revision__ = '$Id: PluginMovieFilmweb.py 721 2007-01-26 20:27:52Z piotrek $'
+__revision__ = '$Id: PluginMovieFilmweb.py 779 2007-06-20 22:11:45Z piotrek $'
 
 # Copyright (c) 2005-2007 Piotr Ożarowski
 #
@@ -31,9 +31,13 @@ plugin_url		= 'www.filmweb.pl'
 plugin_language		= _('Polish')
 plugin_author		= 'Piotr Ożarowski'
 plugin_author_email	= '<ozarow+griffith@gmail.com>'
-plugin_version		= '1.9'
+plugin_version		= '1.11'
 
 class Plugin(movie.Movie):
+	TRAILER_PATTERN     = re.compile("""<a class=["']notSelected["'].*?href=["'](.*?)["']>zwiastuny</a>\s*\[\d+\]\s*&raquo;""")
+	DIRECTOR_PATTERN    = re.compile('yseria\s+(.*)\s+scenariusz', re.MULTILINE)
+	O_TITLE_AKA_PATTERN = re.compile('\(AKA\s+(.*?)\)')
+
 	def __init__(self, id):
 		self.movie_id = 'filmweb'
 		self.url      = str(id)
@@ -48,8 +52,12 @@ class Plugin(movie.Movie):
 
 	def get_o_title(self):
 		self.o_title = gutils.trim(self.page, '<span class="otherTitle">', '<span')
-		self.o_title = string.replace(self.o_title, "\t",'')
-		self.o_title = string.replace(self.o_title, "\n",'')
+		tmp = self.O_TITLE_AKA_PATTERN.findall(self.o_title)
+		if tmp:
+			self.o_title = tmp[0]
+		else:
+			self.o_title = string.replace(self.o_title, "\t",'')
+			self.o_title = string.replace(self.o_title, "\n",'')
 
 	def get_title(self):
 		self.title = gutils.trim(self.page, '<div id="filmTitle">', '<span')
@@ -59,14 +67,14 @@ class Plugin(movie.Movie):
 			self.title = gutils.before(self.title, '(')
 
 	def get_director(self):
-		self.director = re.findall(r'yseria\t+(.*)\t+scenariusz', self.page)
-		if len(self.director)>0:
-			self.director = self.director[0]
+		director = self.DIRECTOR_PATTERN.findall(self.page)
+		if len(director)>0:
+			self.director = director[0]
 			self.director = string.replace(self.director, "\t",'')
+			self.director = re.sub('\s+', ' ', self.director)
 			self.director = string.replace(self.director, ",",", ")
+			self.director = string.replace(self.director, " ,  ",", ")
 			self.director = string.replace(self.director, ",  (wi\xeacej&#160;...)",'')
-		else:
-			self.director = None
 
 	def get_plot(self):
 		self.plot = gutils.trim(self.page," alt=\"o filmie\"/></div>","</div>")
@@ -115,7 +123,9 @@ class Plugin(movie.Movie):
 		self.site = self.url
 
 	def get_trailer(self):
-		self.trailer = ''
+		trailer = self.TRAILER_PATTERN.findall(self.page)
+		if trailer:
+			self.trailer = trailer[0]
 
 	def get_country(self):
 		self.country = gutils.trim(self.page,"\tprodukcja:", '</a>')
@@ -138,19 +148,25 @@ class SearchPlugin(movie.SearchMovie):
 
 	def search(self,parent_window):
 		self.open_search(parent_window)
-		pos = string.find(self.page, 'szukana fraza')
-		if pos == -1:	# only one match!
+		pos = string.find(self.page, 'Znaleziono <b>')
+		if pos == -1:	# movie page
 			self.page = None
-		else:		# multiple matches
-			self.page = gutils.before(self.page[pos:], 'id="sitemap"');
-			self.page = gutils.after(self.page, '<li ')
+		else:		# search results
+			items = gutils.trim(self.page[pos:], '<b>', '</b>')
+			if items == '0':
+				self.page = False
+			else:
+				self.page = gutils.before(self.page[pos:], 'id="sitemap"')
+				self.page = gutils.after(self.page, '<li ')
 		return self.page
 
 	def get_searches(self):
-		if self.page is None:	# immidietly redirection to movie page
+		if self.page is None:	# movie page
 			self.number_results = 1
 			self.ids.append(self.url)
 			self.titles.append(gutils.convert_entities(self.title))
+		elif self.page is False: # no movie found
+			self.number_results = 0
 		else:			# multiple matches
 			elements = string.split(self.page, '<li ')
 			self.number_results = elements[-1]
