@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMovieIMDB.py 737 2007-02-20 15:03:24Z piotrek $'
+__revision__ = '$Id: PluginMovieIMDB.py 785 2007-06-28 22:08:30Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
@@ -22,9 +22,8 @@ __revision__ = '$Id: PluginMovieIMDB.py 737 2007-02-20 15:03:24Z piotrek $'
 # GNU General Public License, version 2 or later
 
 from gettext import gettext as _
-import gutils
-import movie
-import string
+import gutils, movie
+import string, re
 
 plugin_name		= 'IMDb'
 plugin_description	= 'Internet Movie Database'
@@ -32,7 +31,7 @@ plugin_url		= 'www.imdb.com'
 plugin_language		= _('English')
 plugin_author		= 'Vasco Nunes, Piotr Ożarowski'
 plugin_author_email	= 'griffith-private@lists.berlios.de'
-plugin_version		= '1.1'
+plugin_version		= '1.5'
 
 class Plugin(movie.Movie):
 	def __init__(self, id):
@@ -40,6 +39,10 @@ class Plugin(movie.Movie):
 		self.movie_id = id
 		self.url = "http://imdb.com/title/tt%s" % str(self.movie_id)
 
+	def initialize(self):
+		self.cast_page = self.open_page(url=self.url + '/fullcredits')
+		self.plot_page = self.open_page(url=self.url + '/plotsummary')
+
 	def get_image(self):
 		tmp = string.find(self.page, 'a name="poster"')
 		if tmp == -1:		# poster not available
@@ -54,12 +57,22 @@ class Plugin(movie.Movie):
 		self.title = gutils.trim(self.page, '<h1>', ' <span')
 
 	def get_director(self):
-		self.director = gutils.trim(self.page,'<h5>Directed by</h5>', '<br/>\n<br/>')
-		self.director = self.director.replace('<br/>', ', ')
+		pattern = re.compile('<h5>Directors?:</h5>[\n\s\r]*(.*?)(?:<br/>)?(?:<a[^>]+>more</a>)?\n</div')
+		result = pattern.search(self.page)
+		if result:
+			self.director = result.groups()[0]
+			self.director = self.director.replace('<br/>', ', ')
 
 	def get_plot(self):
 		self.plot = gutils.trim(self.page, '<h5>Plot Outline:</h5>', '</div>')
 		self.plot = self.__before_more(self.plot)
+		elements = string.split(self.plot_page, '<p class="plotpar">')
+		if len(elements) > 1:
+			self.plot = self.plot + '\n\n'
+			elements[0] = ''
+			for element in elements:
+				if element <> '':
+					self.plot = self.plot + gutils.strip_tags(gutils.before(element, '</a>')) + '\n'
 
 	def get_year(self):
 		self.year = gutils.trim(self.page, '<a href="/Sections/Years/', '</a>')
@@ -74,7 +87,9 @@ class Plugin(movie.Movie):
 
 	def get_cast(self):
 		self.cast = ''
-		self.cast = gutils.trim(self.page, '<table class="cast">', '</table>')
+		self.cast = gutils.trim(self.cast_page, '<table class="cast">', '</table>')
+		if self.cast == '':
+			self.cast = gutils.trim(self.page, '<table class="cast">', '</table>')
 		self.cast = string.replace(self.cast, ' ... ', _(' as '))
 		self.cast = string.replace(self.cast, '</tr><tr>', "\n")
 		self.cast = string.replace(self.cast, '</tr><tr class="even">', "\n")
@@ -86,7 +101,7 @@ class Plugin(movie.Movie):
 		self.classification = gutils.trim(self.classification, 'Rated ', ' ')
 
 	def get_studio(self):
-		self.studio = ''
+		self.studio = gutils.trim(self.page, '<h5>Company:</h5>', '</a>')
 
 	def get_o_site(self):
 		self.o_site = ''
@@ -101,11 +116,17 @@ class Plugin(movie.Movie):
 		self.country = gutils.trim(self.page, '<h5>Country:</h5>', '</div>')
 
 	def get_rating(self):
-		self.rating = gutils.trim(self.page, '<b>User Rating:</b>', '/10')
-		if self.rating:
-			self.rating = str(float(gutils.clean(self.rating)))
+		self.rating = gutils.trim(self.page, '<b>User Rating:</b> \n<b>', '/10')
+		if self.rating and self.rating.find('awaiting') == -1:
+			try:
+				self.rating = float(self.rating)
+			except Exception, e:
+				self.rating = 0
+		else:
+			self.rating = 0
 
 	def get_notes(self):
+		self.notes = ''
 		language = gutils.trim(self.page, '<h5>Language:</h5>', '</div>')
 		language = gutils.strip_tags(language)
 		color = gutils.trim(self.page, '<h5>Color:</h5>', '</div>')
@@ -131,7 +152,7 @@ class Plugin(movie.Movie):
 		return data
 
 class SearchPlugin(movie.SearchMovie):
-
+	PATTERN = re.compile(r"""<a href=['"]/title/tt([0-9]+)/["']>(.*?)</td>""")
 	def __init__(self):
 		self.original_url_search	= 'http://imdb.com/find?more=tt;q='
 		self.translated_url_search	= 'http://imdb.com/find?more=tt;q='
@@ -139,17 +160,17 @@ class SearchPlugin(movie.SearchMovie):
 
 	def search(self,parent_window):
 		self.open_search(parent_window)
-		self.sub_search()
+		self.page = gutils.trim(self.page, '(Displaying', '<b>Suggestions For Improving Your Results</b>');
+		self.page = self.page.decode('iso-8859-1')
 		return self.page
 
-	def sub_search(self):
-		self.page = gutils.trim(self.page, '</b> found the following results:', '<b>Suggestions For Improving Your Results</b>');
-		self.page = self.page.decode('iso-8859-1')
-
 	def get_searches(self):
-		elements = string.split(self.page, '<li>')
+		elements = string.split(self.page, '<tr>')
 
-		if (elements[0]<>''):
-			for element in elements:
-				self.ids.append(gutils.trim(element, '/title/tt','/?fr='))
-				self.titles.append(gutils.strip_tags(gutils.convert_entities(gutils.trim(element, ';fm=1">', '</li>'))))
+		if len(elements):
+			for element in elements[1:]:
+				match = self.PATTERN.findall(element)
+				if len(match):
+					tmp  = gutils.clean(match[0][1])
+					self.ids.append(match[0][0])
+					self.titles.append(tmp)
