@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMoviePTGate.py 704 2007-01-10 23:56:42Z iznogoud $'
+__revision__ = '$Id: PluginMoviePTGate.py 807 2007-07-06 17:02:35Z iznogoud $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ozarowski
 #
@@ -32,7 +32,7 @@ plugin_url = "www.cinema.ptgate.pt"
 plugin_language = _("Portuguese")
 plugin_author = "Vasco Nunes"
 plugin_author_email="<vasco.m.nunes@gmail.com>"
-plugin_version = "0.3"
+plugin_version = "0.4.1"
 
 class Plugin(movie.Movie):
 	def __init__(self, id):
@@ -50,7 +50,7 @@ class Plugin(movie.Movie):
 		self.title = string.capwords(gutils.trim(self.page,"class=subtitle>","</b><br>") )
 
 	def get_director(self):
-		self.director = gutils.trim(self.page,"<b>realização</b><br>","<br><br><b>")
+		self.director = gutils.trim(self.page,"<b>realizao</b><br>","<br><br><b>")
 
 	def get_plot(self):
 		self.plot = gutils.trim(self.page,"<b>sinopse</b><br>","<br><br>")
@@ -70,6 +70,7 @@ class Plugin(movie.Movie):
 	def get_cast(self):
 		self.cast = ""
 		self.cast = gutils.trim(self.page,"pretes</b><br>","<br><br><b>data de estreia</b><br>")
+		self.cast = string.replace(self.cast,"<br> ","\n")
 		self.cast = string.replace(self.cast,"<br>", "\n")
 		self.cast = gutils.strip_tags(self.cast)
 
@@ -90,9 +91,13 @@ class Plugin(movie.Movie):
 
 	def get_country(self):
 		self.country = gutils.trim(self.page,"s</b><br>","<br><br><b>g")
+		
+	def get_notes(self):
+		self.notes = gutils.trim(self.page,"prmios e nomeaes</b><br><b>", "<td width=6 background='Images/group_r.gif'")
+		self.notes = gutils.strip_tags(self.notes)
 
 	def get_rating(self):
-		tmp=gutils.trim(self.page,"img src='Images/ustar",".gif")
+		tmp=gutils.trim(self.page,"'Images/mstar",".gif")
 		if(tmp):
 			self.rating = float(tmp)
 			if (self.rating>10):
