@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: quick_filter.py 706 2007-01-11 18:06:50Z piotrek $'
+__revision__ = '$Id: quick_filter.py 770 2007-06-12 22:32:20Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 
@@ -39,7 +39,7 @@ def change_filter(self):
 			statement.append_whereclause(self.db.Movie.c[criteria].like('%'+text+'%'))
 	if self.widgets['filter']['text'].is_focus():
 		if len(text)<4: # filter mode
-			limit = int(self.config.get('s_limit', 0))
+			limit = int(self.config.get('limit', 0, section='mainlist'))
 			if limit > 0:
 				statement.limit = limit
 	self.populate_treeview(statement)
