@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__revision__ = '$Id: winsetup.py 739 2007-02-20 16:01:12Z piotrek $'
+__revision__ = '$Id: winsetup.py 827 2007-08-05 18:41:38Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 # This program is free software; you can redistribute it and/or modify
@@ -46,7 +46,7 @@ import py2exe
 
 opts = {
     "py2exe": {
-        "includes": "pygtk,cairo,pangocairo,cgi,PIL,pysqlite2,pysqlite2.*,pango,atk,gobject,tempfile,csv,xml.dom,xml.dom.ext,xml.dom.minidom,xml.sax,threading,htmlentitydefs,sqlalchemy,sqlalchemy.*,sqlalchemy.mods.*,sqlalchemy.databases.*,sqlalchemy.engine.*,sqlalchemy.ext.*,sqlalchemy.orm.*,zipfile,webbrowser,shutil,reportlab,reportlab.pdfgen,reportlab.pdfgen.canvas,reportlab.platypus,reportlab.pdfbase.ttfonts,smtplib,win32com,platform,winshell,psycopg2,MySQLdb,chardet,gzip",
+        "includes": "pygtk,cairo,pangocairo,gobject,cgi,PIL,pysqlite2,pysqlite2.*,pango,atk,gobject,tempfile,csv,xml.dom,xml.dom.ext,xml.dom.minidom,xml.sax,threading,htmlentitydefs,sqlalchemy,sqlalchemy.*,sqlalchemy.mods.*,sqlalchemy.databases.*,sqlalchemy.engine.*,sqlalchemy.ext.*,sqlalchemy.orm.*,zipfile,webbrowser,shutil,reportlab,reportlab.pdfgen,reportlab.pdfgen.canvas,reportlab.platypus,reportlab.pdfbase.ttfonts,smtplib,win32com,platform,winshell,psycopg2,MySQLdb,chardet,gzip,commands",
         "optimize": 2,
 		"dist_dir": "dist",
     }
@@ -54,13 +54,13 @@ opts = {
 
 setup(
     name = "Griffith",
-    version = "0.9.2",
+    version = "0.9.4",
 	description = 'Griffith - A film manager',
     author = 'Vasco Nunes/Piotr Ozarowski',
     author_email = 'vasco.m.nunes@gmail.com',
     url = 'http://griffith.berlios.de',
     license = 'GPL',
-    console = [
+    windows = [
         {
             "script": "griffith",
             "icon_resources": [(1, "images\griffith.ico")]
@@ -87,22 +87,36 @@ setup(
 		glob.glob("i18n\\bg\\LC_MESSAGES\\*.mo")),
 		("i18n/cs/LC_MESSAGES",
 		glob.glob("i18n\\cs\\LC_MESSAGES\\*.mo")),
+		("i18n/da/LC_MESSAGES",
+		glob.glob("i18n\\da\\LC_MESSAGES\\*.mo")),
 		("i18n/de/LC_MESSAGES",
 		glob.glob("i18n\\de\\LC_MESSAGES\\*.mo")),
+		("i18n/el/LC_MESSAGES",
+		glob.glob("i18n\\el\\LC_MESSAGES\\*.mo")),
 		("i18n/es/LC_MESSAGES",
 		glob.glob("i18n\\es\\LC_MESSAGES\\*.mo")),
+		("i18n/ja/LC_MESSAGES",
+		glob.glob("i18n\\ja\\LC_MESSAGES\\*.mo")),
 		("i18n/fr/LC_MESSAGES",
 		glob.glob("i18n\\fr\\LC_MESSAGES\\*.mo")),
 		("i18n/pl/LC_MESSAGES",
 		glob.glob("i18n\\pl\\LC_MESSAGES\\*.mo")),
 		("i18n/pt/LC_MESSAGES",
 		glob.glob("i18n\\pt\\LC_MESSAGES\\*.mo")),
+		("i18n/ru/LC_MESSAGES",
+		glob.glob("i18n\\ru\\LC_MESSAGES\\*.mo")),
 		("i18n/it/LC_MESSAGES",
 		glob.glob("i18n\\it\\LC_MESSAGES\\*.mo")),
+		("i18n/nl/LC_MESSAGES",
+		glob.glob("i18n\\nl\\LC_MESSAGES\\*.mo")),
 		("i18n/sv/LC_MESSAGES",
 		glob.glob("i18n\\sv\\LC_MESSAGES\\*.mo")),
+		("i18n/tr/LC_MESSAGES",
+		glob.glob("i18n\\tr\\LC_MESSAGES\\*.mo")),
 		("i18n/pt_BR/LC_MESSAGES",
 		glob.glob("i18n\\pt_BR\\LC_MESSAGES\\*.mo")),
+		("i18n/zh_CN/LC_MESSAGES",
+		glob.glob("i18n\\zh_CN\\LC_MESSAGES\\*.mo")),
 		("lib/plugins",
 		glob.glob("lib\\plugins\\*.*")),
 		("lib/plugins/export",
@@ -113,6 +127,6 @@ setup(
 		glob.glob("lib\\plugins\\imp\\*.*")),
 		("images",
 		glob.glob("images\\*.png")),
-		("",
+		("lib",
 		glob.glob("lib\\*.*"))],
 )
